==> rrdtool_1.5.5.orig.tar.gz: rrdtool-1.x-1.5.5/README.md <==
RRDtool - Round Robin Database Tool
===================================

RRDTool 1.x master build status: [![Build Status](https://travis-ci.org/oetiker/rrdtool-1.x.png?branch=master)](https://travis-ci.org/oetiker/rrdtool-1.x)
test coverage [![Coverage Status](https://coveralls.io/repos/oetiker/rrdtool-1.x/badge.png?branch=master)](https://coveralls.io/r/oetiker/rrdtool-1.x?branch=master)

RRDtool 1.5.x build status: [![Build Status](https://travis-ci.org/oetiker/rrdtool-1.x.png?branch=1.5)](https://travis-ci.org/oetiker/rrdtool-1.x)

RRDtool is a little program for easily maintaining a database of time-series
data. It comes with a charting program for drawing pretty graphs based on
the data stored.

It is pretty easy to gather status information from all sorts of things,
ranging from the temperature in your office to the number of octets which
have passed through the FDDI interface of your router. But it is not so
trivial to store this data in a efficient and systematic manner. This is
where RRDtool kicks in. It lets you log and analyze the data you gather from
all kinds of data-sources (DS). The data analysis part of RRDtool is based
on the ability to quickly generate graphical representations of the data
values collected over a definable time period.


To compile:
-----------

check out the instructions in [[doc/rrdbuild.pod]]

Getting Started:
----------------

Either after compiling or after installing you can try the example
RRDtool applications in the examples directory.

To learn:
---------

Read the documentation in the doc directory.

If you are looking for a more slow paced introduction, make sure to read
Alex van den Bogaerdt's rrdtutorial which is also available from the doc
directory. Also read his cdeftutorial and Steve Rader's rpntutorial.
 
If you want to know about the format of the log files check
[[src/rrd_format.h]] there are a lot of comments in there ...

How to make Tobi happy:
-----------------------

If you want to show your appreciation for RRDtool you could make me happy
by going to http://tobi.oetiker.ch/wish and ordering a CD from
my CD wish list ... 

How to keep in touch:
---------------------

There are 3 Mailing lists for RRDtool:

rrd-announce	LOW volume RRDtool Announcements List (Only Stable Releases)
rrd-users       For discussion amongst people who use RRDtool in their applications
rrd-developers  For people who actually HACK RRDtool code

To subscribe to <MAILGLIST> send a message with the subject 'subscribe'
to <MAILGLIST>-request@lists.oetiker.ch

Note, that postings to rrd-announce will always be cross-posted 
to rrd-users and rrd-developers as well.

To Contribute:
--------------

Contributed feature and bug patches are most welcome. Since rrdtool lives on
github, it is now very easy to create pull requests. Work from the master
branch unless you are creating bugfixes. No new features should go into the
1.2, 1.3 and 1.4 branches.

If you contribute new features, make sure to also update the documentation
pod files.

The latest released Version:
-------------------
Is always available from http://oss.oetiker.ch/rrdtool/


Tobias Oetiker <tobi@oetiker.ch>

==> rrdtool_1.7.0.orig.tar.gz: rrdtool-1.x-1.7.0/README.md <==
RRDtool - Round Robin Database Tool
===================================

[![Join the chat at https://gitter.im/oetiker/rrdtool-1.x](https://badges.gitter.im/oetiker/rrdtool-1.x.svg)](https://gitter.im/oetiker/rrdtool-1.x?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

RRDTool 1.x master build status: [![Build Status](https://travis-ci.org/oetiker/rrdtool-1.x.png?branch=master)](https://travis-ci.org/oetiker/rrdtool-1.x)
test coverage [![Coverage Status](https://coveralls.io/repos/oetiker/rrdtool-1.x/badge.png?branch=master)](https://coveralls.io/r/oetiker/rrdtool-1.x?branch=master)

RRDtool 1.6.x build status: [![Build Status](https://travis-ci.org/oetiker/rrdtool-1.x.png?branch=1.6)](https://travis-ci.org/oetiker/rrdtool-1.x)

RRDtool is a little program for easily maintaining a database of time-series
data. It comes with a charting program for drawing pretty graphs based on
the data stored.

It is pretty easy to gather status information from all sorts of things,
ranging from the temperature in your office to the number of octets which
have passed through the FDDI interface of your router. But it is not so
trivial to store this data in a efficient and systematic manner. This is
where RRDtool kicks in. It lets you log and analyze the data you gather from
all kinds of data-sources (DS). The data analysis part of RRDtool is based
on the ability to quickly generate graphical representations of the data
values collected over a definable time period.


To compile:
-----------

check out the instructions in [[doc/rrdbuild.pod]]

Getting Started:
----------------

Either after compiling or after installing you can try the example
RRDtool applications in the examples directory.

To learn:
---------

Read the documentation in the doc directory.

If you are looking for a more slow paced introduction, make sure to read
Alex van den Bogaerdt's rrdtutorial which is also available from the doc
directory. Also read his cdeftutorial and Steve Rader's rpntutorial.
 
If you want to know about the format of the log files check
[[src/rrd_format.h]] there are a lot of comments in there ...

How to make Tobi happy:
-----------------------

If you want to show your appreciation for RRDtool you could make me happy
by going to http://tobi.oetiker.ch/wish and ordering a CD from
my CD wish list ... 

How to keep in touch:
---------------------

There are 3 Mailing lists for RRDtool:

rrd-announce	LOW volume RRDtool Announcements List (Only Stable Releases)
rrd-users       For discussion amongst people who use RRDtool in their applications
rrd-developers  For people who actually HACK RRDtool code

To subscribe to <MAILGLIST> send a message with the subject 'subscribe'
to <MAILGLIST>-request@lists.oetiker.ch

Note, that postings to rrd-announce will always be cross-posted 
to rrd-users and rrd-developers as well.

To Contribute:
--------------

Contributed feature and bug patches are most welcome. Since rrdtool lives on
github, it is now very easy to create pull requests. Work from the master
branch unless you are creating bugfixes. No new features should go into the
1.2, 1.3 and 1.4 branches.

If you contribute new features, make sure to also update the documentation
pod files.

The latest released Version:
-------------------
Is always available from http://oss.oetiker.ch/rrdtool/


Tobias Oetiker <tobi@oetiker.ch>
